import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import { formatDatetime, formatMoney } from '@billogram/format';
import getRanges from './getRanges';
import mergeOverlappingRanges from './mergeOverlappingRanges';

function getFormattedValue(value) {
  var type = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'default';

  switch (type) {
    case 'date':
      {
        return formatDatetime(Number(value));
      }

    case 'money':
      {
        return formatMoney(value);
      }

    default:
      {
        return value.toString();
      }
  }
}

function getFormattedQuery(terms) {
  var type = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'default';

  switch (type) {
    case 'date':
      {
        return terms.map(function (value) {
          return formatDatetime(Number(value));
        });
      }

    case 'money':
      {
        return terms.map(function (value) {
          return formatMoney(value);
        });
      }

    default:
      {
        return terms.map(function (value) {
          return value.toString();
        });
      }
  }
}

export default function highlight(value, terms, type, callback) {
  var formattedValue = getFormattedValue(value);
  var formattedTerms = getFormattedQuery(terms);
  var ranges = getRanges(formattedValue, formattedTerms);
  var merged = mergeOverlappingRanges(ranges);
  var currentIndex = 0;
  var parts = [];
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = merged[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var _step$value = _slicedToArray(_step.value, 2),
          _start = _step$value[0],
          _end = _step$value[1];

      if (_start > currentIndex) {
        parts.push(formattedValue.slice(currentIndex, _start));
      }

      parts.push(callback(formattedValue.slice(_start, _end), _start, _end));
      currentIndex = _end;
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return != null) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  if (currentIndex < formattedValue.length) {
    parts.push(formattedValue.slice(currentIndex));
  }

  return parts;
}
//# sourceMappingURL=highlight.js.map